# Review at https://bugzilla.redhat.com/show_bug.cgi?id=540034

%{!?_unitdir: %global _unitdir %{_prefix}/lib/systemd/system/}
%global momorel 1
%global git_snapshot 1

%if 0%{?git_snapshot}
%global git_rev  a548c73e35d62ec334df5cd3a491ee409d0067bd
%global git_date 20161111
%global git_short %(echo %{git_rev} | cut -c-8)
%global git_version D%{git_date}git%{git_short}
%endif

Name:           lxdm
Version:        0.5.3
Release:        5%{?git_version:.%{?git_version}}.%{momorel}m%{?dist}
Summary:        Lightweight X11 Display Manager

Group:          User Interface/Desktops
License:        GPLv2+ and LGPLv2+
URL:            http://lxde.org

%if 0%{?git_snapshot}
Source0:        %{name}-%{version}-%{?git_version}.tar.bz2
%else
Source0:        http://downloads.sourceforge.net/sourceforge/lxdm/%{name}-%{version}.tar.xz
%endif

# systemd service file and preset
Source1:        lxdm.service
Source2:        lxdm.preset

# Fedora pam setting
Source10:		pam.lxdm

# Shell script to create tarball from git scm
Source100:      create-tarball-from-git.sh

## Patches needing discussion with the upstream

## Distro specific patches ##

# Distro artwork, start on vt1
Patch50:        lxdm-0.4.1-config.patch
Patch60:        lxdm-0.5.1-ssh-agent-on-start.patch


BuildRequires:  pkgconfig(gtk+-2.0) >= 2.12.0
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pam-devel
BuildRequires:  intltool >= 0.40.0
%if 0%{?git_snapshot}
BuildRequires:  automake
BuildRequires:  libtool
%endif
Requires:       pam
#Requires:       /sbin/shutdown
#Requires:       desktop-backgrounds-compat
Requires:		%{_bindir}/ssh-agent
# needed for anaconda to boot into runlevel 5 after install
Provides:       service(graphical-login) = lxdm

%if 0%{?fedora} >= 18
BuildRequires:  systemd
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
%endif


%description
LXDM is the future display manager of LXDE, the Lightweight X11 Desktop 
environment. It is designed as a lightweight alternative to replace GDM or 
KDM in LXDE distros. It's still in very early stage of development.


%prep
%setup -q %{?git_version:-n %{name}-%{version}-%{?git_version}}

%patch50 -p1 -b .config
%patch60 -p1 -b .ssh_agent

sed -i.reset data/lxdm.conf.in \
	-e '\@reset@s|^.*$|reset=1|' 

install -cpm 644  %{SOURCE10} pam/lxdm

cat << EOF > tempfiles.lxdm.conf
d %{_localstatedir}/run/%{name} 0755 root root
EOF

%build
%{?git_version:sh autogen.sh}
%configure \
	--disable-silent-rules \
	--disable-consolekit \
	%{nil}
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} INSTALL='install -p'
%find_lang %{name}

# these files are not in the package, but should be owned by lxdm 
touch %{buildroot}%{_sysconfdir}/%{name}/xinitrc
mkdir -p %{buildroot}%{_localstatedir}/run/%{name}
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}
touch %{buildroot}%{_localstatedir}/lib/%{name}.conf

%if 0%{?fedora} >= 15
install -Dpm 644 tempfiles.lxdm.conf %{buildroot}%{_prefix}/lib/tmpfiles.d/lxdm.conf
%endif

install -Dpm 644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
install -m644 -p -D %{SOURCE2} %{buildroot}%{_unitdir}-preset/83-fedora-lxdm.preset


%post
%systemd_post %{name}.service


%preun
%systemd_preun %{name}.service


%postun
%systemd_postun


%files -f %{name}.lang
# FIXME add ChangeLog and NEWS if not empty
%doc AUTHORS COPYING README TODO gpl-2.0.txt lgpl-2.1.txt
%dir %{_sysconfdir}/%{name}
%ghost %config(noreplace,missingok) %{_sysconfdir}/%{name}/xinitrc
%config(noreplace) %attr(755,root,root) %{_sysconfdir}/%{name}/Xsession
%config(noreplace) %attr(755,root,root) %{_sysconfdir}/%{name}/LoginReady
%config(noreplace) %attr(755,root,root) %{_sysconfdir}/%{name}/PostLogin
%config(noreplace) %attr(755,root,root) %{_sysconfdir}/%{name}/PostLogout
%config(noreplace) %attr(755,root,root) %{_sysconfdir}/%{name}/PreLogin
%config(noreplace) %attr(755,root,root) %{_sysconfdir}/%{name}/PreReboot
%config(noreplace) %attr(755,root,root) %{_sysconfdir}/%{name}/PreShutdown
%config %{_sysconfdir}/%{name}/lxdm.conf
%config(noreplace) %{_sysconfdir}/pam.d/%{name}

%{_bindir}/%{name}-config
%{_sbindir}/%{name}
%{_sbindir}/lxdm-binary
%{_libexecdir}/lxdm-greeter-gtk
%{_libexecdir}/lxdm-greeter-gdk
%{_libexecdir}/lxdm-numlock
%{_libexecdir}/lxdm-session
%{_datadir}/%{name}/

%if 0%{?fedora} >= 15
%config(noreplace) %{_prefix}/lib/tmpfiles.d/lxdm.conf
%endif

%{_unitdir}/lxdm.service
%{_unitdir}-preset/83-fedora-lxdm.preset

%ghost %dir %{_localstatedir}/run/%{name}
%dir %{_localstatedir}/lib/%{name}
%ghost %{_localstatedir}/lib/%{name}.conf


%changelog
* Mon Dec 19 2016 Masanobu Sato <satoshiga@momonga-linux.org>
- (0.5.3-5.D20161111gita548c73e.1m)
- Update and import from Fedora

* Mon Jun 20 2011 Yohsuke Ooi <meke@momonga-linux.org>
- (0.2.0-5m)
- no Req upstart

* Mon Apr 11 2011 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (0.2.0-4m)
- rebuild for new GCC 4.6

* Sun Nov 28 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (0.2.0-3m)
- rebuild for new GCC 4.5

* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (0.2.0-2m)
- full rebuild for mo7 release

* Tue Aug  3 2010 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (0.2.0-1m)
- import from Rawhide

